@@ -5,7 +5,8 @@ from . import config
 from .url_handler import epHandler
 from .misc import entry, error, read_json
 
-class Seasonal():
+
+class Seasonal:
     def __init__(self):
         self.entry = entry()
 
@@ -15,7 +16,7 @@ class Seasonal():
             {"name": {
                 "ep_list": [[ep, ep-link], [], ...],
                 "category_url": "https://"
-                }, 
+                },
              "another anime": {
                  ...
                 },
@@ -27,39 +28,37 @@ class Seasonal():
         categ_urls = []
         user_eps = []
         for i in names:
-            categ_urls.append(self.json[i]['category_url'])
-            user_eps.append(self.json[i]['ep'])
+            categ_urls.append(self.json[i]["category_url"])
+            user_eps.append(self.json[i]["ep"])
 
         latest_urls = {}
         for i, e, n in zip(categ_urls, user_eps, names):
             self.entry.category_url = i
-            ep_class = epHandler(self.entry) 
+            ep_class = epHandler(self.entry)
             latest = ep_class.get_latest()
-            eps_range = list(range(e + 1, latest + 1))             
+            eps_range = list(range(e, latest + 1))
             ep_urls = []
             for j in eps_range:
                 self.entry.ep = j
                 ep_class = epHandler(self.entry)
                 entry = ep_class.gen_eplink()
                 ep_urls.append([j, entry.ep_url])
-            
-            latest_urls.update({n: {
-                'ep_list': ep_urls, 'category_url': i}}) 
 
-        return latest_urls 
+            latest_urls.update({n: {"ep_list": ep_urls, "category_url": i}})
+
+        return latest_urls
 
     def read_save_data(self):
-        self.json = read_json(config.seasonal_file_path)    
+        self.json = read_json(config.seasonal_file_path)
 
     def write_seasonals(self):
         try:
-            with config.seasonal_file_path.open('w') as f:
+            with config.seasonal_file_path.open("w") as f:
                 json.dump(self.json, f)
 
         except PermissionError:
-                error("Unable to write to history file due permissions.")
-                sys.exit()
-
+            error("Unable to write to history file due permissions.")
+            sys.exit()
 
     def update_show(self, name, categ_url):
         self.read_save_data()
@@ -68,25 +67,20 @@ class Seasonal():
             return 0
 
         self.entry.category_url = categ_url
-        self.json[name]['ep'] = epHandler(self.entry).get_latest()
+        self.json[name]["ep"] = epHandler(self.entry).get_latest()
         self.write_seasonals()
 
     def add_show(self, name, categ_url, start_ep):
-       self.read_save_data()
+        self.read_save_data()
 
-       if name in [x for x in self.json]:
-           return 0
+        if name in [x for x in self.json]:
+            return 0
 
-       dic = {
-           name: {
-               'ep': start_ep,
-               'category_url': categ_url
-           }
-       }
+        dic = {name: {"ep": start_ep, "category_url": categ_url}}
+
+        self.json.update(dic)
+        self.write_seasonals()
 
-       self.json.update(dic)
-       self.write_seasonals()
-    
     def del_show(self, name):
         self.read_save_data()
 
@@ -98,6 +92,5 @@ class Seasonal():
 
     def list_seasonals(self):
         self.read_save_data()
-        
-        return [[i, self.json[i]['ep']] for i in self.json]
 
+        return [[i, self.json[i]["ep"]] for i in self.json]
